@@ -11,7 +11,7 @@ test_that(".valid_dbcon works", {
 test_that(".insert_data et al work", {
     db_file <- tempfile()
     db <- dbConnect(SQLite(), db_file)
-    .insert_data(db, mm8_file, storage = "long")
+    .insert_data(db, a_file, storage = "long")
     res <- dbListTables(db)
     expect_equal(res, c("msms_spectrum", "msms_spectrum_peak"))
     spd <- dbGetQuery(db, "select * from msms_spectrum")
@@ -19,7 +19,7 @@ test_that(".insert_data et al work", {
     spd$centroided <- as.logical(spd$centroided)
     spd$spectrum_id_ <- NULL
     spd$dataStorage <- NULL
-    ref <- as.data.frame(spectraData(mm8_sps))
+    ref <- as.data.frame(spectraData(a_sps))
     ref$dataStorage <- NULL
     expect_equal(ref, spd)
 
@@ -31,13 +31,13 @@ test_that(".insert_data et al work", {
         z
     })
     names(pks) <- NULL
-    expect_equal(as.list(peaksData(mm8_sps)), pks)
+    expect_equal(as.list(peaksData(a_sps)), pks)
     dbDisconnect(db)
     file.remove(db_file)
 
     db_file <- tempfile()
     db <- dbConnect(SQLite(), db_file)
-    .insert_data(db, mm8_file, storage = "blob")
+    .insert_data(db, a_file, storage = "blob")
     res <- dbListTables(db)
     expect_equal(res, c("msms_spectrum", "msms_spectrum_peak_blob"))
     dbDisconnect(db)
@@ -45,7 +45,7 @@ test_that(".insert_data et al work", {
 
     db_file <- tempfile()
     db <- dbConnect(SQLite(), db_file)
-    .insert_data(db, mm8_file, storage = "blob2")
+    .insert_data(db, a_file, storage = "blob2")
     res <- dbListTables(db)
     expect_equal(res, c("msms_spectrum", "msms_spectrum_peak_blob2"))
     dbDisconnect(db)
@@ -57,7 +57,7 @@ test_that(".insert_data et al work", {
     db <- as(db, "DummySQL")
     with_mocked_bindings(
         ".is_maria_db" = function(x) TRUE,
-        code = .insert_data(db, mm8_file)
+        code = .insert_data(db, a_file)
     )
     dbDisconnect(db)
     file.remove(db_file)
@@ -68,7 +68,7 @@ test_that(".insert_data et al work", {
     with_mocked_bindings(
         ".db_requires_peak_id" = function(x) TRUE,
         code = expect_true(
-            .insert_data(con = con_test, c(mm8_file, mm14_file),
+            .insert_data(con = con_test, c(a_file, b_file),
                          storage = "long"))
     )
     res <- dbGetQuery(con_test, "select * from msms_spectrum_peak")
@@ -80,12 +80,12 @@ test_that(".insert_data et al work", {
 })
 
 test_that(".set_backend_insert_data works", {
-    s <- Spectra(c(mm8_file, mm14_file))
+    s <- Spectra(c(a_file, b_file))
     expect_error(.set_backend_insert_data(s, f = c(1, 2, 3)), "match length")
 
     ## blob2
     con_ref <- dbConnect(SQLite(), tempfile())
-    createMsBackendSqlDatabase(con_ref, c(mm8_file, mm14_file), blob = TRUE,
+    createMsBackendSqlDatabase(con_ref, c(a_file, b_file), blob = TRUE,
                                peaksStorageMode = "blob2")
     be_ref <- backendInitialize(MsBackendSql(), dbcon = con_ref)
 
@@ -105,7 +105,7 @@ test_that(".set_backend_insert_data works", {
 
     ## blob; No chunk-wise processing
     con_ref <- dbConnect(SQLite(), tempfile())
-    createMsBackendSqlDatabase(con_ref, c(mm8_file, mm14_file), blob = TRUE,
+    createMsBackendSqlDatabase(con_ref, c(a_file, b_file), blob = TRUE,
                                peaksStorageMode = "blob")
     be_ref <- backendInitialize(MsBackendSql(), dbcon = con_ref)
     con_test <- dbConnect(SQLite(), tempfile())
@@ -124,7 +124,7 @@ test_that(".set_backend_insert_data works", {
 
     ## long; Arbitrary chunks.
     con_ref <- dbConnect(SQLite(), tempfile())
-    createMsBackendSqlDatabase(con_ref, c(mm8_file, mm14_file), blob = FALSE)
+    createMsBackendSqlDatabase(con_ref, c(a_file, b_file), blob = FALSE)
     be_ref <- backendInitialize(MsBackendSql(), dbcon = con_ref)
     con_test <- dbConnect(SQLite(), tempfile())
     f <- sort(rep(1:10, length.out = length(s)))
@@ -175,7 +175,7 @@ test_that("createMsBackendSqlDatabase works", {
     expect_false(createMsBackendSqlDatabase(cn))
 
     expect_error(createMsBackendSqlDatabase("b", "b"), "valid connection")
-    expect_true(createMsBackendSqlDatabase(cn, mm8_file))
+    expect_true(createMsBackendSqlDatabase(cn, a_file))
 
     dbDisconnect(cn)
 
@@ -197,28 +197,28 @@ test_that(".fetch_peaks_data_long works", {
     expect_equal(.fetch_peaks_data_long(MsBackendSql(), columns = "intensity",
                                         drop = TRUE), list())
 
-    res <- .fetch_peaks_data_long(mm8_be_long)
+    res <- .fetch_peaks_data_long(a_be_long)
     expect_true(is.list(res))
-    ref <- peaksData(mm8_sps@backend)
+    ref <- peaksData(a_sps@backend)
     expect_equal(res, ref)
-    res <- .fetch_peaks_data_long(mm8_be_long, columns = "intensity")
+    res <- .fetch_peaks_data_long(a_be_long, columns = "intensity")
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1]]))
-    expect_equal(unlist(res), unlist(mm8_sps$intensity))
-    res <- .fetch_peaks_data_long(mm8_be_long, columns = "intensity",
+    expect_equal(unlist(res), unlist(a_sps$intensity))
+    res <- .fetch_peaks_data_long(a_be_long, columns = "intensity",
                                   drop = TRUE)
     expect_true(is.list(res))
-    expect_equal(res, as.list(mm8_sps$intensity))
+    expect_equal(res, as.list(a_sps$intensity))
 
     ## subsets.
-    a <- mm8_be_long[c(4, 1, 4, 5, 1, 3)]
-    b <- mm8_sps@backend[c(4, 1, 4, 5, 1, 3)]
+    a <- a_be_long[c(4, 1, 4, 5, 1, 3)]
+    b <- a_sps@backend[c(4, 1, 4, 5, 1, 3)]
     expect_equal(.fetch_peaks_data_long(a), peaksData(b))
     expect_equal(.fetch_peaks_data_long(a, "mz", TRUE), as.list(b$mz))
 
     ## spectra without peaks data.
-    a <- mm8_be_long[c(1:10)]
-    a@spectraIds <- c(a@spectraIds, 200L)
+    a <- a_be_long[c(1:10)]
+    a@spectraIds <- c(a@spectraIds, 2000L)
     res <- .fetch_peaks_data_long(a)[[length(a) + 1L]]
     expect_true(is.matrix(res))
     expect_true(nrow(res) == 0L)
@@ -243,31 +243,31 @@ test_that(".fetch_peaks_data_blob works", {
     expect_equal(.fetch_peaks_data_blob(MsBackendSql(), columns = "intensity",
                                         drop = TRUE), list())
 
-    res <- .fetch_peaks_data_blob(mm8_be_blob)
+    res <- .fetch_peaks_data_blob(a_be_blob)
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1L]]))
     expect_equal(colnames(res[[1L]]), c("mz", "intensity"))
-    ref <- peaksData(mm8_sps@backend)
+    ref <- peaksData(a_sps@backend)
     expect_equal(res, ref)
-    res <- .fetch_peaks_data_blob(mm8_be_blob,
+    res <- .fetch_peaks_data_blob(a_be_blob,
                                   columns = c("intensity", "mz"))
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1L]]))
     expect_equal(colnames(res[[1L]]), c("intensity", "mz"))
 
-    res <- .fetch_peaks_data_blob(mm8_be_blob, columns = "intensity")
+    res <- .fetch_peaks_data_blob(a_be_blob, columns = "intensity")
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1L]]))
     expect_equal(colnames(res[[1L]]), "intensity")
-    expect_equal(unlist(res), unlist(mm8_sps$intensity))
-    res <- .fetch_peaks_data_blob(mm8_be_blob, columns = "intensity",
+    expect_equal(unlist(res), unlist(a_sps$intensity))
+    res <- .fetch_peaks_data_blob(a_be_blob, columns = "intensity",
                                   drop = TRUE)
     expect_true(is.list(res))
-    expect_equal(res, as.list(mm8_sps$intensity))
+    expect_equal(res, as.list(a_sps$intensity))
 
     ## subsets.
-    a <- mm8_be_blob[c(4, 1, 4, 5, 1, 3)]
-    b <- mm8_sps@backend[c(4, 1, 4, 5, 1, 3)]
+    a <- a_be_blob[c(4, 1, 4, 5, 1, 3)]
+    b <- a_sps@backend[c(4, 1, 4, 5, 1, 3)]
     expect_equal(.fetch_peaks_data_blob(a), peaksData(b))
     expect_equal(.fetch_peaks_data_blob(a, "mz", TRUE), as.list(b$mz))
 })
@@ -279,40 +279,40 @@ test_that(".fetch_peaks_data_blob2 works", {
     expect_equal(.fetch_peaks_data_blob2(MsBackendSql(), columns = "intensity",
                                         drop = TRUE), list())
 
-    res <- .fetch_peaks_data_blob2(mm8_be_blob2)
+    res <- .fetch_peaks_data_blob2(a_be_blob2)
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1L]]))
     expect_equal(colnames(res[[1L]]), c("mz", "intensity"))
-    ref <- peaksData(mm8_sps@backend)
+    ref <- peaksData(a_sps@backend)
     expect_equal(res, ref)
-    res <- .fetch_peaks_data_blob2(mm8_be_blob2,
+    res <- .fetch_peaks_data_blob2(a_be_blob2,
                                    columns = c("intensity", "mz"))
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1L]]))
     expect_equal(colnames(res[[1L]]), c("intensity", "mz"))
 
-    res <- .fetch_peaks_data_blob2(mm8_be_blob2, columns = "intensity")
+    res <- .fetch_peaks_data_blob2(a_be_blob2, columns = "intensity")
     expect_true(is.list(res))
     expect_true(is.matrix(res[[1L]]))
     expect_equal(colnames(res[[1L]]), "intensity")
-    expect_equal(unlist(res), unlist(mm8_sps$intensity))
-    res <- .fetch_peaks_data_blob2(mm8_be_blob2, columns = "intensity",
+    expect_equal(unlist(res), unlist(a_sps$intensity))
+    res <- .fetch_peaks_data_blob2(a_be_blob2, columns = "intensity",
                                    drop = TRUE)
     expect_true(is.list(res))
-    expect_equal(res, as.list(mm8_sps$intensity))
+    expect_equal(res, as.list(a_sps$intensity))
 
     ## subsets.
-    a <- mm8_be_blob2[c(4, 1, 4, 5, 1, 3)]
-    b <- mm8_sps@backend[c(4, 1, 4, 5, 1, 3)]
+    a <- a_be_blob2[c(4, 1, 4, 5, 1, 3)]
+    b <- a_sps@backend[c(4, 1, 4, 5, 1, 3)]
     expect_equal(.fetch_peaks_data_blob2(a), peaksData(b))
     expect_equal(.fetch_peaks_data_blob2(a, "mz", TRUE), as.list(b$mz))
 })
 
 test_that(".fetch_spectra_data_sql works", {
-    res <- .fetch_spectra_data_sql(mm8_be_long, columns = c("rtime", "msLevel"))
+    res <- .fetch_spectra_data_sql(a_be_long, columns = c("rtime", "msLevel"))
     expect_true(is.data.frame(res))
     expect_identical(colnames(res), c("rtime", "msLevel"))
-    expect_identical(length(mm8_be_long), nrow(res))
+    expect_identical(length(a_be_long), nrow(res))
 })
 
 test_that(".disable_mysql_keys works", {
@@ -322,38 +322,38 @@ test_that(".disable_mysql_keys works", {
 })
 
 test_that(".spectra_data_sql works", {
-    expect_error(.spectra_data_sql(mm8_be_long, c("rtime", "other_col")),
+    expect_error(.spectra_data_sql(a_be_long, c("rtime", "other_col")),
                  "other_col not available.")
-    res <- .spectra_data_sql(mm8_be_long, c("rtime", "msLevel", "mz"))
+    res <- .spectra_data_sql(a_be_long, c("rtime", "msLevel", "mz"))
     expect_s4_class(res, "DataFrame")
     expect_identical(colnames(res), c("rtime", "msLevel", "mz"))
-    expect_identical(length(mm8_be_long), nrow(res))
+    expect_identical(length(a_be_long), nrow(res))
     expect_s4_class(res$mz, "NumericList")
 
     expect_error(
-        .spectra_data_sql(mm8_be_long, columns = c("rtime", "other_column")),
+        .spectra_data_sql(a_be_long, columns = c("rtime", "other_column")),
         " not available.")
 
-    tmp <- mm8_be_long[c(3, 2, 2, 3, 1, 10, 1)]
+    tmp <- a_be_long[c(3, 2, 2, 3, 1, 10, 1)]
     res <- .spectra_data_sql(tmp, c("rtime", "msLevel", "mz"))
     expect_identical(colnames(res), c("rtime", "msLevel", "mz"))
     expect_identical(length(tmp), nrow(res))
     expect_s4_class(res$mz, "NumericList")
 
-    tmp_sps <- mm8_sps[c(3, 2, 2, 3, 1, 10, 1)]
+    tmp_sps <- a_sps[c(3, 2, 2, 3, 1, 10, 1)]
     expect_equal(tmp_sps$mz, res$mz)
     expect_equal(tmp_sps$rtime, res$rtime)
     expect_equal(tmp_sps$intensity, tmp$intensity)
 
     ## blob
-    tmp <- mm8_be_blob[c(3, 2, 2, 3, 1, 10, 1)]
+    tmp <- a_be_blob[c(3, 2, 2, 3, 1, 10, 1)]
     res <- .spectra_data_sql(tmp, c("rtime", "msLevel", "mz"))
     expect_identical(colnames(res), c("rtime", "msLevel", "mz"))
     expect_identical(length(tmp), nrow(res))
     expect_s4_class(res$mz, "NumericList")
 
     expect_error(
-        .spectra_data_sql(mm8_be_blob, columns = c("rtime", "other_column")),
+        .spectra_data_sql(a_be_blob, columns = c("rtime", "other_column")),
         " not available.")
 
     expect_equal(tmp_sps$mz, res$mz)
@@ -371,16 +371,16 @@ test_that(".db_data_type works", {
 })
 
 test_that(".available_peaks_variables works", {
-    res <- .available_peaks_variables(mm8_be_long)
+    res <- .available_peaks_variables(a_be_long)
     expect_equal(res, c("mz", "intensity"))
 
-    res <- .available_peaks_variables(mm8_be_blob)
+    res <- .available_peaks_variables(a_be_blob)
     expect_equal(res, c("mz", "intensity"))
 
-    res <- .available_peaks_variables(mm8_be_blob2)
+    res <- .available_peaks_variables(a_be_blob2)
     expect_equal(res, c("mz", "intensity"))
 
-    a <- mm8_be_blob2[integer()]
+    a <- a_be_blob2[integer()]
     res <- .available_peaks_variables(a)
     expect_equal(res, c("mz", "intensity"))
 
@@ -389,9 +389,9 @@ test_that(".available_peaks_variables works", {
 })
 
 test_that(".has_local_variable works", {
-    res <- .has_local_variable(mm8_be_long, c("other_id"))
+    res <- .has_local_variable(a_be_long, c("other_id"))
     expect_false(res)
-    tmp <- mm8_be_long
+    tmp <- a_be_long
     tmp$other_id <- "a"
     res <- .has_local_variable(tmp, c("other_id"))
     expect_true(res)
@@ -433,26 +433,26 @@ test_that(".precursor_mz_query works", {
 })
 
 test_that(".db_info_string works", {
-    res <-.db_info_string(mm8_be_long)
+    res <-.db_info_string(a_be_long)
     expect_true(is.character(res))
     expect_true(length(res) == 1L)
 })
 
 test_that(".combine works", {
-    tmp <- split(mm8_be_long[1:10], 1:10)
+    tmp <- split(a_be_long[1:10], 1:10)
     res <- .combine(tmp)
     expect_s4_class(res, "MsBackendSql")
-    expect_equal(mm8_be_long[1:10], res)
+    expect_equal(a_be_long[1:10], res)
 
-    tmp <- .combine(list(mm8_be_long))
-    expect_equal(length(tmp), length(mm8_be_long))
-    expect_equal(rtime(tmp), rtime(mm8_be_long))
+    tmp <- .combine(list(a_be_long))
+    expect_equal(length(tmp), length(a_be_long))
+    expect_equal(rtime(tmp), rtime(a_be_long))
 
-    a <- mm8_be_long[1:10]
+    a <- a_be_long[1:10]
     b <- setBackend(Spectra(a), MsBackendMemory())@backend
     expect_error(.combine(list(a, b)), "Can only merge backends of the same")
 
-    expect_error(.combine(list(mm8_be_long, mm_be)), "connected to the same")
+    expect_error(.combine(list(a_be_long, mm_be)), "connected to the same")
 })
 
 test_that(".initialize_tables works", {
@@ -558,19 +558,19 @@ test_that(".insert_backend works", {
         ".insert_peaks" = function(...) {},
         ".is_maria_db" = function(x) TRUE,
         code = expect_true(
-            length(.insert_backend(3, mm8_sps, partitionBy = "chunk", 1L)) == 2L
+            length(.insert_backend(3, a_sps, partitionBy = "chunk", 1L)) == 2L
         )
     )
     ## Insert in long form
     tf <- tempfile()
     tmp <- dbConnect(SQLite(), tf)
-    sv <- spectraVariables(mm8_sps)
-    spd <- as.data.frame(spectraData(mm8_sps[1:2], columns = sv))
+    sv <- spectraVariables(a_sps)
+    spd <- as.data.frame(spectraData(a_sps[1:2], columns = sv))
     cols <- .db_data_type(tmp, spd)
     .initialize_tables(tmp, cols)
-    res <- .insert_backend(tmp, mm8_sps, index = 77, peak_index = 13)
+    res <- .insert_backend(tmp, a_sps, index = 77, peak_index = 13)
     expect_true(is.list(res))
-    expect_equal(res$spectrum_id, length(mm8_sps) + 77)
+    expect_equal(res$spectrum_id, length(a_sps) + 77)
     expect_equal(res$peak_id, 13)
     res <- dbGetQuery(tmp, "select * from msms_spectrum")
     expect_equal(res$spectrum_id_, seq(78, length.out = nrow(res)))
@@ -582,18 +582,18 @@ test_that(".insert_backend works", {
     ## Insert with peak ID.
     tf <- tempfile()
     tmp <- dbConnect(SQLite(), tf)
-    sv <- spectraVariables(mm8_sps)
-    spd <- as.data.frame(spectraData(mm8_sps[1:2], columns = sv))
+    sv <- spectraVariables(a_sps)
+    spd <- as.data.frame(spectraData(a_sps[1:2], columns = sv))
     cols <- .db_data_type(tmp, spd)
     with_mocked_bindings(
         ".db_requires_peak_id" = function(x) TRUE,
         code = {
             .initialize_tables(tmp, cols = cols)
-            l <- .insert_backend(tmp, mm8_sps, index = 77, peak_index = 13)
+            l <- .insert_backend(tmp, a_sps, index = 77, peak_index = 13)
         }
     )
     expect_true(is.list(l))
-    expect_equal(l$spectrum_id, length(mm8_sps) + 77)
+    expect_equal(l$spectrum_id, length(a_sps) + 77)
     res <- dbGetQuery(tmp, "select * from msms_spectrum")
     expect_equal(res$spectrum_id_, seq(78, length.out = nrow(res)))
     res <- dbGetQuery(tmp, "select * from msms_spectrum_peak")
@@ -643,18 +643,18 @@ test_that(".create_from_spectra_data works", {
     ## wrong format or missing data.
     tmpf <- tempfile()
     tmpcon <- dbConnect(SQLite(), tmpf)
-    dta <- spectraData(mm8_sps)
+    dta <- spectraData(a_sps)
     expect_error(.create_from_spectra_data(tmpcon, dta), "required")
 
     ## blob
     dta <- spectraData(
-        mm8_sps, columns = c(spectraVariables(mm8_sps), "mz", "intensity"))
+        a_sps, columns = c(spectraVariables(a_sps), "mz", "intensity"))
     .create_from_spectra_data(tmpcon, dta, peaksStorageMode = "blob")
     res <- backendInitialize(MsBackendSql(), dbcon = tmpcon)
-    expect_true(all(mm8_sps$dataStorage != res$dataStorage))
-    expect_equal(rtime(mm8_be_long), rtime(res))
-    expect_equal(mz(mm8_be_long), mz(res))
-    expect_equal(intensity(mm8_be_long), intensity(res))
+    expect_true(all(a_sps$dataStorage != res$dataStorage))
+    expect_equal(rtime(a_be_long), rtime(res))
+    expect_equal(mz(a_be_long), mz(res))
+    expect_equal(intensity(a_be_long), intensity(res))
     tbls <- dbListTables(tmpcon)
     expect_equal(tbls, c("msms_spectrum", "msms_spectrum_peak_blob"))
 
@@ -678,23 +678,23 @@ test_that(".create_from_spectra_data works", {
     tbls <- dbListTables(tmpcon)
     expect_equal(tbls, c("msms_spectrum", "msms_spectrum_peak"))
     res2 <- backendInitialize(MsBackendSql(), dbcon = tmpcon)
-    expect_true(all(res2$dataStorage != mm8_be_long$dataStorage))
-    expect_equal(rtime(res2), rtime(mm8_be_long))
-    expect_equal(mz(res2), mz(mm8_be_long))
-    expect_equal(intensity(res2), intensity(mm8_be_long))
+    expect_true(all(res2$dataStorage != a_be_long$dataStorage))
+    expect_equal(rtime(res2), rtime(a_be_long))
+    expect_equal(mz(res2), mz(a_be_long))
+    expect_equal(intensity(res2), intensity(a_be_long))
     dbDisconnect(tmpcon)
 
     ## empty data frame
     tmpf <- tempfile()
     tmpcon <- dbConnect(SQLite(), tmpf)
     dta <- spectraData(
-        mm8_sps[integer()],
-        columns = c(spectraVariables(mm8_sps), "mz", "intensity"))
+        a_sps[integer()],
+        columns = c(spectraVariables(a_sps), "mz", "intensity"))
     .create_from_spectra_data(tmpcon, dta)
     res3 <- backendInitialize(MsBackendSql(), dbcon = tmpcon)
     expect_true(validObject(res3))
-    expect_equal(spectraVariables(mm8_be_long), spectraVariables(res3))
-    expect_equal(colnames(spectraData(mm8_be_long)),
+    expect_equal(spectraVariables(a_be_long), spectraVariables(res3))
+    expect_equal(colnames(spectraData(a_be_long)),
                  colnames(spectraData(res3)))
     expect_true(length(res3) == 0L)
     dbDisconnect(tmpcon)
@@ -723,7 +723,7 @@ test_that(".create_from_spectra_data works", {
     tmpcon <- dbConnect(SQLite(), tmpf)
     tmpcon <- as(tmpcon, "DummySQL")
     dta <- spectraData(
-        mm8_sps, columns = c(spectraVariables(mm8_sps), "mz", "intensity"))
+        a_sps, columns = c(spectraVariables(a_sps), "mz", "intensity"))
     ## With mock to simulate MariaDB
     with_mocked_bindings(
         ".insert_spectra_variables" = function(...) TRUE,
@@ -767,30 +767,30 @@ test_that("MsBackendSql works with duckdb", {
         ## long format
         db_file <- tempfile()
         db <- dbConnect(duckdb(), db_file)
-        .insert_data(db, mm8_file, storage = "long")
+        .insert_data(db, a_file, storage = "long")
         res <- dbListTables(db)
         expect_equal(res, c("msms_spectrum", "msms_spectrum_peak"))
         tmp <- backendInitialize(MsBackendSql(), dbcon = db)
-        expect_equal(rtime(tmp), rtime(mm8_sps))
-        expect_equal(centroided(tmp), centroided(mm8_sps))
-        expect_equal(msLevel(tmp), msLevel(mm8_sps))
-        expect_equal(mz(tmp), mz(mm8_sps))
-        expect_equal(intensity(tmp), intensity(mm8_sps))
+        expect_equal(rtime(tmp), rtime(a_sps))
+        expect_equal(centroided(tmp), centroided(a_sps))
+        expect_equal(msLevel(tmp), msLevel(a_sps))
+        expect_equal(mz(tmp), mz(a_sps))
+        expect_equal(intensity(tmp), intensity(a_sps))
         dbDisconnect(db)
         file.remove(db_file)
 
         ## blob2
         db_file <- tempfile()
         db <- dbConnect(duckdb(), db_file)
-        .insert_data(db, mm8_file, storage = "blob2")
+        .insert_data(db, a_file, storage = "blob2")
         res <- dbListTables(db)
         expect_equal(res, c("msms_spectrum", "msms_spectrum_peak_blob2"))
         tmp <- backendInitialize(MsBackendSql(), dbcon = db)
-        expect_equal(rtime(tmp), rtime(mm8_sps))
-        expect_equal(centroided(tmp), centroided(mm8_sps))
-        expect_equal(msLevel(tmp), msLevel(mm8_sps))
-        expect_equal(mz(tmp), mz(mm8_sps))
-        expect_equal(intensity(tmp), intensity(mm8_sps))
+        expect_equal(rtime(tmp), rtime(a_sps))
+        expect_equal(centroided(tmp), centroided(a_sps))
+        expect_equal(msLevel(tmp), msLevel(a_sps))
+        expect_equal(mz(tmp), mz(a_sps))
+        expect_equal(intensity(tmp), intensity(a_sps))
         dbDisconnect(db)
         file.remove(db_file)
     }
@@ -798,13 +798,13 @@ test_that("MsBackendSql works with duckdb", {
 
 test_that(".db_is_long_form works", {
     expect_equal(.db_is_long_form(MsBackendSql()), NA)
-    expect_true(.db_is_long_form(mm8_be_long))
-    expect_false(.db_is_long_form(mm8_be_blob))
-    expect_false(.db_is_long_form(mm8_be_blob2))
+    expect_true(.db_is_long_form(a_be_long))
+    expect_false(.db_is_long_form(a_be_blob))
+    expect_false(.db_is_long_form(a_be_blob2))
 })
 
 test_that(".fetch_long_form_sql works", {
-    tmp <- mm8_be_long
+    tmp <- a_be_long
     ## only spectra variables
     res <- .fetch_long_form_sql(tmp, c("rtime", "msLevel", "scanIndex"))
     expect_true(is.data.frame(res))
@@ -813,7 +813,7 @@ test_that(".fetch_long_form_sql works", {
     expect_equal(res$scanIndex, tmp$scanIndex)
     ## arbitrary order
     idx <- c(4, 1, 9, 20)
-    tmp <- mm8_be_long[idx]
+    tmp <- a_be_long[idx]
     res <- .fetch_long_form_sql(tmp, c("rtime", "msLevel", "scanIndex"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("rtime", "msLevel", "scanIndex"))
@@ -821,7 +821,7 @@ test_that(".fetch_long_form_sql works", {
     expect_equal(res$scanIndex, tmp$scanIndex)
     ## duplicated order
     idx <- c(4, 1, 4, 9, 20, 4)
-    tmp <- mm8_be_long[idx]
+    tmp <- a_be_long[idx]
     res <- .fetch_long_form_sql(tmp, c("rtime", "msLevel", "scanIndex"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("rtime", "msLevel", "scanIndex"))
@@ -829,7 +829,7 @@ test_that(".fetch_long_form_sql works", {
     expect_equal(res$scanIndex, tmp$scanIndex)
 
     ## only peak variables
-    tmp <- mm8_be_long
+    tmp <- a_be_long
     res <- .fetch_long_form_sql(tmp, c("mz"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("mz"))
@@ -837,7 +837,7 @@ test_that(".fetch_long_form_sql works", {
 
     ## arbitrary order
     idx <- c(3, 9, 1, 30, 5)
-    tmp <- mm8_be_long[idx]
+    tmp <- a_be_long[idx]
     res <- .fetch_long_form_sql(tmp, c("mz"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("mz"))
@@ -845,14 +845,14 @@ test_that(".fetch_long_form_sql works", {
 
     ## duplicated order
     idx <- c(4, 1, 3, 1, 100, 1, 4)
-    tmp <- mm8_be_long[idx]
+    tmp <- a_be_long[idx]
     res <- .fetch_long_form_sql(tmp, c("mz"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("mz"))
     expect_equal(res$mz, unlist(tmp$mz))
 
     ## peak and spectra variables
-    tmp <- mm8_be_long
+    tmp <- a_be_long
     res <- .fetch_long_form_sql(tmp, c("scanIndex", "rtime", "intensity"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("scanIndex", "rtime", "intensity"))
@@ -862,7 +862,7 @@ test_that(".fetch_long_form_sql works", {
 
     ## arbitrary order
     idx <- c(4, 9, 1, 3, 13)
-    tmp <- mm8_be_long[idx]
+    tmp <- a_be_long[idx]
     res <- .fetch_long_form_sql(tmp, c("scanIndex", "rtime", "intensity"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("scanIndex", "rtime", "intensity"))
@@ -872,7 +872,7 @@ test_that(".fetch_long_form_sql works", {
 
     ## duplicated order
     idx <- c(4, 9, 1, 4, 13, 1, 9)
-    tmp <- mm8_be_long[idx]
+    tmp <- a_be_long[idx]
     res <- .fetch_long_form_sql(tmp, c("scanIndex", "rtime", "intensity"))
     expect_true(is.data.frame(res))
     expect_equal(colnames(res), c("scanIndex", "rtime", "intensity"))
@@ -885,16 +885,16 @@ test_that(".fetch_long_form_sql works", {
 
 test_that(".requires_peak_id works", {
     ## For not it returns only TRUE if a duckdb database is used.
-    expect_false(.requires_peak_id(mm8_be_long))
-    expect_false(.requires_peak_id(mm8_be_blob))
+    expect_false(.requires_peak_id(a_be_long))
+    expect_false(.requires_peak_id(a_be_blob))
 })
 
 test_that(".has_peak_id works", {
-    expect_false(.has_peak_id(mm8_be_blob))
-    expect_false(.has_peak_id(mm8_be_long))
+    expect_false(.has_peak_id(a_be_blob))
+    expect_false(.has_peak_id(a_be_long))
     expect_false(.has_peak_id(MsBackendSql()))
 })
 
 test_that(".db_requires_peak_id works", {
-    expect_false(.db_requires_peak_id(mm8_be_long@dbcon))
+    expect_false(.db_requires_peak_id(a_be_long@dbcon))
 })
